#!/bin/sh -e
# This script can be called in the following ways:
#
# After the package was removed:
#       <postrm> remove
#
# After the package was purged:
#       <postrm> purge
#
# After the package was upgraded:
#       <old-postrm> upgrade <new-version>
# if that fails:
#       <new-postrm> failed-upgrade <old-version>
#
#
# After all of the packages files have been replaced:
#       <postrm> disappear <overwriting-package> <version>
#
#
# If preinst fails during install:
#       <new-postrm> abort-install
#
# If preinst fails during upgrade of removed package:
#       <new-postrm> abort-install <old-version>
#
# If preinst fails during upgrade:
#       <new-postrm> abort-upgrade <old-version>


# Update the initramfs
update_initramfs()
{
	if which update-initramfs >/dev/null 2>&1; then
		update-initramfs -u
	fi
}


case "$1" in
    remove)
	update_initramfs
	;;

    purge)
	rm -f /etc/usplash.conf
	;;
    upgrade|failed-upgrade|disappear|abort-install|abort-upgrade)
	;;

    *)
	echo "$0 called with unknown argument \`$1'" 1>&2
	exit 1
	;;
esac

# Automatically added by dh_installinit
if [ "$1" = "purge" ] ; then
	update-rc.d usplash remove >/dev/null || exit $?
fi
# End automatically added section


exit 0
